pub struct LockFile { /* private fields */ }Expand description
A PID-based lockfile for mutual exclusion.
Implementations
Sourceimpl LockFile
impl LockFile
Sourcepub fn acquire(path: &Path) -> Result<Self, CoreError>
pub fn acquire(path: &Path) -> Result<Self, CoreError>
Try to acquire the lockfile. Returns error if already locked by a running process.
Sourcepub fn try_acquire(path: &Path) -> Option<Self>
pub fn try_acquire(path: &Path) -> Option<Self>
Try to acquire the lockfile, returning None if already locked (instead of an error). Used by –auto mode to silently skip when another process is running.